@@ -5,12 +5,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
 use List::SomeUtils qw(first_index);
 use List::Util qw(shuffle uniq);
+use MIDI::RtMidi::ScorePlayer ();
 use Music::Scales qw(get_scale_MIDI get_scale_notes);
 use Music::Chord::Note ();
 use Music::Note ();
@@ -248,7 +249,7 @@ MIDI::RtController::Filter::Gene - Gene's RtController filters
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -408,8 +409,8 @@ B<scale> attributes.
 
 =head2 delay_tone
 
-Play a delayed note, or series of notes, based on the given event note
-and B<delay> attribute.
+Play a delayed note, or series of notes, based on the given event
+note, and the B<delay> and B<feedback> attributes.
 
 =head2 offset_tone
 
@@ -427,10 +428,14 @@ setting.
 
 =head1 SEE ALSO
 
-L<Moo>
-
 L<List::SomeUtils>
 
+L<List::Util>
+
+L<MIDI::RtMidi::ScorePlayer>
+
+L<Moo>
+
 L<Music::Scales>
 
 L<Music::Chord::Note>
@@ -441,6 +446,8 @@ L<Music::ToRoman>
 
 L<Music::VoiceGen>
 
+L<Types::Standard>
+
 =head1 AUTHOR
 
 Gene Boggs <gene.boggs@gmail.com>
